#
# spec file for package ripgrep
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ripgrep
Version:        12.1.1
Release:        bp153.1.14
Summary:        A search tool that combines ag with grep
License:        MIT AND Unlicense
Group:          Productivity/Text/Utilities
URL:            https://github.com/BurntSushi/ripgrep
Source:         https://github.com/BurntSushi/ripgrep/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  cargo
BuildRequires:  rust >= 1.31
BuildRequires:  rubygem(asciidoctor)

%description
ripgrep is a line oriented search tool that combines the usability of
The Silver Searcher (similar to ack) with the raw speed of GNU grep.
ripgrep works by recursively searching your current directory
for a regex pattern.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       bash-completion
Supplements:    (%{name} and bash)
BuildArch:      noarch

%description bash-completion
The official bash completion script for ripgrep, generated during the build.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
The official zsh completion script for ripgrep, generated during the build.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
The official fish completion script for ripgrep, generated during the build.

%prep
%setup -q
%setup -q -D -T -a 1
mkdir cargo-home
cat >cargo-home/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = './vendor'
EOF

%build
export CARGO_HOME=$PWD/cargo-home
cargo build --release %{?_smp_mflags}

%install
export CARGO_HOME=$PWD/cargo-home
cargo install --path . --root=%{buildroot}%{_prefix}

# remove residue crate file
rm %{buildroot}%{_prefix}/.crates.toml
rm -f %{buildroot}%{_prefix}/.crates2.json

install -Dm 644 target/release/build/ripgrep-*/out/rg.1 %{buildroot}%{_mandir}/man1/rg.1
install -Dm 644 target/release/build/ripgrep-*/out/rg.bash %{buildroot}%{_datadir}/bash-completion/completions/rg
install -Dm 644 target/release/build/ripgrep-*/out/rg.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/rg.fish
install -Dm 644 complete/_rg %{buildroot}%{_datadir}/zsh/site-functions/_rg

%files
%license LICENSE-MIT UNLICENSE
%doc CHANGELOG.md README.md
%{_mandir}/man1/rg.1%{?ext_man}
%{_bindir}/rg

%files bash-completion
%{_datadir}/bash-completion

%files fish-completion
%{_datadir}/fish

%files zsh-completion
%{_datadir}/zsh

%changelog
* Tue Jul 28 2020 Martin Rey <mrey@suse.com>
- ripgrep 12.1.1
  * Corrects some egregious markup output in --help (#1581)
  * Mention the special $0 capture group in docs for the
  - r/--replace flag. (#1591)
  * Fix failing test resulting from out-of-sync dependencies.
    (#1602)
* Fri May 15 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ripgrep 12.1.0
  * many bug fixes
  * performance improvements
  * --no-pcre2-unicode deprecated in favor of --no-unicode
  * --auto-hybrid-regex deprecated in favor of --engine auto
  * supports decompressing .Z files via uncompress
- drop ripgrep-11.0.2-reproducible-manpage.patch, now upstream
* Thu Apr 30 2020 Martin Wilck <mwilck@suse.com>
- Remove transient file .crates2.json during build
* Wed Mar 25 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add ripgrep-11.0.2-reproducible-manpage.patch (boo#1100677)
* Mon Nov 11 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 11.0.2
  * See included CHANGELOG.md for the complete changelog
* Sun Sep 16 2018 Avindra Goolcharan <avindra@opensuse.org>
- Updated to version 0.10.0
- Breaking change
  * The match semantics of -w/--word-regexp have changed slightly.
    They used to be \b(?:<your pattern>)\b. Now, it's
    (?:^|\W)(?:<your pattern>)(?:$|\W). This matches the behavior
    of GNU grep and is believed to be closer to the intended
    semantics of the flag.
- Features
  * Add -U/--multiline flag that permits matching over multiple lines.
  * Add -P/--pcre2 flag that gives support for look-around and
    backreferences.
  * Add --json flag that prints results in a JSON Lines format.
  * --one-file-system flag to skip directories on different file systems.
  * Add --sort and --sortr flag for more sorting. Deprecate --sort-files.
  * The --trim flag strips prefix whitespace from all lines printed.
  * Add --null-data flag, which makes ripgrep use NUL as a line terminator.
  * The --passthru flag now works with the --replace flag.
  * Add --line-buffered and --block-buffered for forcing a buffer strategy.
  * Add --pre-glob for filtering files through the --pre flag.
- Bug fixes
  * Searching with non-zero context can now use memory maps if
    appropriate.
  * ripgrep will now stop correctly when its output pipe is closed.
  * The -w/--word-regexp flag now works more intuitively.
  * Detection of readable stdin has improved on Windows.
  * Matching empty lines now works correctly in several corner cases.
  * Color escape sequences now coalesce, which reduces output size.
  * ripgrep is now more robust with respect to memory maps failing.
  * Color escape sequences are no longer emitted for empty matches.
  * Context from the --passthru flag should not impact process exit status.
  * Fixes bug in ignore crate where first path was always treated
    as a symlink.
  * Read stderr asynchronously when running a process.
  * Add compile time and runtime CPU features to --version output.
  * Don't complete bare pattern after -f in zsh.
* Mon Aug 27 2018 jengelh@inai.de
- Update RPM groups and summary.
* Sun Aug 26 2018 viktor.saevars@gmail.com
- Updated to version 0.9.0
- Breaking changes
  * When --count and --only-matching are provided simultaneously,
    the behavior of ripgrep is as if the --count-matches flag was given.
  * Octal syntax is no longer supported.
  * The --line-number-width flag has been removed.
- Features
  * Added a --stats flag, which emits aggregate statistics
    after search results.
  * lz4 support when using the -z flag
  * Added --no-ignore-global that permits disabling global gitignores
  * Renamed --maxdepth to --max-depth
  * Added a --pre option to filter with an arbitrary program
  * Improved zsh completion
- Bug fixes
  * No longer skips tar archives when -z is used
  * Ignore gitignore files if outside of a repository
  * Use more descriptive error messages
* Tue Mar 13 2018 avindra@opensuse.org
- reduce tarball sizes
  * source tarball taken as is from github
  * vendor tarball compressed with xz
  - cleanup with spec-cleaner
  - port history to ripgrep.changes
  - mark as dual licensed with MIT
  - split completion scripts off into separate packages
* Fri Mar  9 2018 viktor.saevars@gmail.com
- Use version 0.8.1
  - Generate man file
  - Add check
  - Remove empty post and postun
* Sun Oct  8 2017 viktor.saevars@gmail.com
- Inital packaging @ 0.6.0
